// Prep Data for Matlab
// Author: 		SGanapati
// Project:		BRAXPMKT
// Created:		2014/01/20
// Modified:	2014/06/02

// Brazil Data 
global root    "/Users/sharat/Dropbox/Economics/2013_Multiproduct_AGM/Data/"
global root    "/gpfs/home/fas/arkolakis/sg596/2013_Multiproducts/Data/"
global BA_main "$root/Brazil Data"
global XW_main "$root/NACE xWalk"
global OUTPUT  "$root/Output"

// Stage 1
cap program drop Stage_1_alt

program Stage_1_alt 
		* Find Top Exporters// By number of exporters to destination
		keep if currnum == 1
		collapse (count) value_count = value, by(wtfkey)
		gsort -value
		keep if _n<=80			// Number of Countries to keep
		list
		keep wtf
		gen dest = _n
		saveold "$OUTPUT/TEMP", replace
		
end

// Stage 2
cap program drop Stage_2

program Stage_2 
		* Create Obs for Top Exporters
		keep firmid wtfkey
		duplicates drop
		merge m:1 wtf  using "$OUTPUT/TEMP"
		keep if _merge ==3
		drop _merge
		
		expand 100   			// Number of Products to keep
		sort firmid  dest
		gen currnum = mod(_n,100)+1		
		sort firmid  dest currnum
		saveold "$OUTPUT/TEMP", replace
end

// Stage 3
cap program drop Stage_3

program Stage_3 
		* Get Sales Data
		*drop if goods>=25
		keep firmid wtfkey value goods currnum
		merge m:1 firmid  wtf currnum  using "$OUTPUT/TEMP"
		sort firm  wtf curr
		drop if dest == .
		drop _merge
		
	 	drop wtf
	 	drop goods
		reshape wide value , i(firm currnum) j(dest )
		drop firm currnum
end


// Load in Brazil Data
// Export For Matlab
cap program drop Matlab_Proc_Alt

program Matlab_Proc_Alt 

	* Find Top Exporters
	use "`1'" , replace
	Stage_1_alt
	
	* Create Obs for Top Exporters
	use "`1'" , replace
	Stage_2
	 
	* Get Sales Data
	use "`1'" , replace
	Stage_3
	outsheet using "`2'", replace comma
end

	

/// Keep MFG Firms That make MFG Goods
use "$BA_main/Raw/prodsales-rais-2000-struct.dta" , replace

	preserve
	collapse (sum) value
	list
	restore
	
	// Merge in ISIC Data
	merge m:1 hs6dgt using "$BA_main/Raw/prodsales-data-2000-hs2isic.dta"
	//browse if _merge == 2
	drop if _merge == 2
	drop _merge
	
	// Merge in NAICS Data
	gen nace_2 = floor(cnae/1000)
	merge m:1 nace_2 using "$XW_main/nace_2"
	drop if _merge == 2 
	drop _merge
	
	// Keep MFG that makes MFG Goods
	keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399
	
	preserve
	collapse (sum) value
	list
	restore
	
	saveold "$OUTPUT/prodsales-rais-2000-nowholesale-mfged", replace

/// NAICS8 FOR Robustness
use "$BA_main/Raw/prodsales-rais-2000-struct-ncm8.dta" , replace
	
	preserve
	collapse (sum) value
	list
	restore
	
	gen hs6dgt = floor(ncm8/100)
	// Merge in ISIC Data
	merge m:1 hs6dgt using "$BA_main/Raw/prodsales-data-2000-hs2isic.dta"
	//browse if _merge == 2
	drop if _merge == 2
	drop _merge
	
	keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399

	preserve
	collapse (sum) value
	list
	restore
	saveold "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-hs8", replace




// Demean Product Sales by HS2 code
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	
	gen hs1 = floor(hs6/100000)
	gen hs2 = floor(hs6/10000)
	gen hs3 = floor(hs6/1000)
	gen hs4 = floor(hs6/100)
	gen hs5 = floor(hs6/10)
	// Demean
	// Take exp(log(value)-mean(log(value)|HS))
	egen mean_lnvalue_prod = mean(log(value)), by(hs2) // Change this to nace_1 or nace_2
	gen value_demean = exp(lnvalue - mean_lnvalue_prod)

	// Take exp(log(value)-log(mean(value|HS)))
	egen mean_value_prod = mean(value), by(hs2)
//	gen value_demean = exp(log(value) - log(mean_value_prod))

	replace value = value_demean
	keep firmid cnae wtfkey hs* value goods isic2 nace*
	egen currnum = rank(value), unique by(firmid wtf)
	replace currnum = goods - currnum + 1

	sort wtf goods firmid currnum
	saveold "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-adj", replace



// Keep "High Tech" Only
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
		//DK	Manufacture of machinery and equipment n.e.c.
		//DL	Manufacture of electrical and optical equipment
		//DM	Manufacture of transport equipment
	keep if regexm(nace_1,"DK|DL|DM")
	saveold "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-highvol", replace


// Process Full
	Matlab_Proc_Alt "$OUTPUT/prodsales-rais-2000-nowholesale-mfged"             "$OUTPUT/Brazil_Matlab_80co_100pr_mfged_count.csv"
	Matlab_Proc_Alt "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-adj"         "$OUTPUT/Brazil_Matlab_80co_100pr_mfged_adj_count.csv"
	Matlab_Proc_Alt "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-highvol" 	"$OUTPUT/Brazil_Matlab_40co_100pr_mfged_highvol_count.csv"
	Matlab_Proc_Alt "$OUTPUT/prodsales-rais-2000-nowholesale-mfged-hs8" 	    "$OUTPUT/Brazil_Matlab_40co_100pr_mfged_hs8_count.csv"

// Rankings
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	collapse (sum) value, by(firmid wtfkey) fast
	collapse (count) n_firms=firmid (sum) value, by(wtfkey) fast
	gsort -n_firms
	list in 1/10
	keep if _n<=10
	gen rank = _n
	label var rank   "Rank"
	label var wtfkey "Destination"
	label var n_firm "\# Exporters"
	label var value "Export Value USD"
	format n_firm %8.0fc
	format value %14.0fc
	decode wtfkey , generate(Destination)
	drop wtfkey 	
	order rank Destination n_firm value
	list
	outsheet using "$OUTPUT/Table_country-ranking.txt", replace
//	net install texsave.pkg	
//	texsave * using "$OUTPUT/Table_country-ranking.tex", frag replace varlabels

	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	collapse (sum) value, by(hs*) fast
	gsort -value
	list in 1/10
	keep if _n<=10
	gen rank = _n
	order rank
	label var rank   "Rank"
	label var hs6     "HS 6-Digit Code"
	label var value   "Export Value"
	format value %14.0fc
	list
	outsheet using "$OUTPUT/Table_country-ranking.txt", replace
//	net install texsave.pkg	
//	texsave * using "$OUTPUT/Table_product-ranking.tex", frag replace varlabels

 
// Testing for deltas
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	tab wtfkey if floor(wtfkey/100000) == 3
	gen LAC =0
	replace LAC = 1 if floor(wtfkey/100000) == 3 
	gen lngood = ln(good)
	gen lncurr = ln(currnum)
	
	// I USE THE BELOW IN THE PAPER
	// Fact 1; part 1
	areg    lnvalue c.lngood##i.LAC if currnum == 1   , absorb(firmid) cluster(firmid)
	quietly: gen used = e(sample) 
	quietly: count if 	currnum == 1  & used == 1
	quietly: by firmid, sort: gen nvals = _n ==1 if used == 1
    quietly: replace nvals = sum(nvals)
    quietly: replace nvals = nvals[_N]
	summarize nvals
	
	// Fact 1; part 2
	areg    lnvalue c.lngood if currnum == good, absorb(firmid) cluster(firmid)
	areg    lnvalue c.lngood##i.LAC if currnum == good, absorb(firmid) cluster(firmid)
	
	// Figure 2
	areg   c.lngood i.LAC if currnum == 1   , absorb(firmid) cluster(firmid)
	
	//Our data reveals the relative prominence of core-competency versus product-specific taste shocks. For each given HS 6-digit product that a firm sells in the Argentina we correlate the firm-product’s rank elsewhere with the firm-product’s Argentinean rank. We find a correlation coefficient of .785 and a Spearman’s rank correlation coefficient of .860.
	// INSERT CODE
	
// Scope - Average Scale relationship
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	tab wtfkey if floor(wtfkey/100000) == 3
	gen LAC =0
	replace LAC = 1 if floor(wtfkey/100000) == 3 
	
	collapse (mean) goods (sum) value, by(firmid wtf cnae LAC nace*)
	gen average_value = value/goods
	
	gen ln_average_value = log(average_value)
	gen ln_goods = log(goods)
	
	//	Fact 3
	//	// Within CNAE/Destination
	areg ln_average_value c.ln_goods i.wtf if LAC == 0, absorb(cnae) cluster(wtf)
	areg ln_average_value c.ln_goods i.wtf if LAC == 1, absorb(cnae) cluster(wtf)
	
	// Within Firm/Destination
	areg ln_average_value ln_goods i.wtf if LAC == 0, absorb(firmid) cluster(firmid)
	areg ln_average_value ln_goods i.wtf if LAC == 1, absorb(firmid) cluster(firmid)
	
// Online Supp
	use "$OUTPUT/prodsales-rais-2000-nowholesale-mfged" , replace
	keep firmid wtfkey goods
	duplicates drop
	sort goods
	codebook goods
	summarize goods
	// Show that max is under 414
