function [ sales_data,sales_data_original ] = generate_data_wrapper( gen, o )
%generate_data_wrapper Wrapper to generate data

    if gen.simulate == 1
        display('---------------')
        display('Generate Fake Data')
        display('---------------')
        
        rng(234943)
        
        gen.('J') = 333333;
        
        Export_ratio = [
                        0.0140
                        0.0099
                        0.0072
                        0.0071
                        0.0056
                        0.0039];

        if o.phicountry        == 1
            unif_list=1:-1/gen.('J'):0;
            phiratio_df    = repmat(unif_list(1,1:gen.('J')),gen.('N'),1);    % Randomly assign a productivty for each destination
        else
            phiratio_df    = rand(gen.('N'),gen.('J'));                % Ratios
        end
    
        xi_norm		= randn(gen.('G'),gen.('N'),gen.('J'));	% Normally distributed
        fd			= rand(gen.('N'),1);					% Fixed Costs per destination
        fd(1)		= 1;

        if o.do_EKK == 1
            c_fake           = randn(gen.('N'),gen.('J'));                % Fixed Cost Shock
            c_fake = permute(repmat(c_fake,[1 1 gen.('G')]),[3 1 2]);
            make_original_data  = @(x) generate_data_EKK(fd, Export_ratio,phiratio_df, xi_norm, c_fake, gen,  x(1:6) );

        else
            rands = -log(1-rand(gen.('N'),1)*.8-.2);
            rands = sort(rands./max(rands),'descend');
            Md			= round(rands*gen.('J')/2);	      % Number of Firms per Destination
            Md			= max(Md,1);					  % Make sure one producer
            make_original_data  = @(x) generate_data    (fd, Md,phiratio_df, xi_norm,         gen,  x(1:6) );
        end
        
        if     strcmp(gen.type,'SA')
        	sales_data  = make_original_data([-1.2	  1.84	  1.89	  1.73	  0.53	  0.00]);
        elseif strcmp(gen.type,'ROW')
        	sales_data  = make_original_data([-0.9	  1.84	  1.89	  1.73	  0.53	  0.00]);
        end
        
        sales_data_original = sales_data;
        
    else
        load(gen.source)
        
        if     strcmp(gen.type,'SA')
            countries = [ 1 2 4 5 6 7 8 10 13 19 25 26 27 29 30 36 37 40 42 50 59 60 61 63 65 67 70 74 ]

        elseif strcmp(gen.type,'SA_noAR')
            countries = [ 2 4 5 6 7 8 10 13 19 25 26 27 29 30 36 37 40 42 50 59 60 61 63 65 67 70 74 ]

        elseif strcmp(gen.type,'ROW')
            countries = [ 3 9 11 12 14 15 16 17 18 20 21 22 23 24 28 31 32 33 34 35 38 39 41 43 44 45 46 47 48 49 51 52 53 54 55 56 57 58 62 64 66 68 69 71 72 73 75 76 77 78 79 80 ]

        elseif strcmp(gen.type,'ROW_noUS')
            countries = [ 9 11 12 14 15 16 17 18 20 21 22 23 24 28 31 32 33 34 35 38 39 41 43 44 45 46 47 48 49 51 52 53 54 55 56 57 58 62 64 66 68 69 71 72 73 75 76 77 78 79 80 ]

        elseif strcmp(gen.type,'ME')
            countries = [ 1 2 5 ]

        elseif strcmp(gen.type,'noME_SA')
            countries = [ 4 6 7 8 10 13 19 25 26 27 29 30 36 37 40 42 50 59 60 61 63 65 67 70 74 ]

		elseif strcmp(gen.type,'noME')
			countries1 = [ 3 9 11 12 14 15 16 17 18 20 21 22 23 24 28 31 32 33 34 35 38 39 41 43 44 45 46 47 48 49 51 52 53 54 55 56 57 58 62 64 66 68 69 71 72 73 75 76 77 78 79 80 ];
			countries2 =[ 4 6 7 8 10 13 19 25 26 27 29 30 36 37 40 42 50 59 60 61 63 65 67 70 74 ];
			countries = [countries1 countries2];
			countries = sort(countries)
		elseif strcmp(gen.type,'NA')
			countries = [ 3 17 ]

		elseif strcmp(gen.type,'EU')
			countries = [ 9 11 12 14 15 16 18 22 46 47 48 51 57 58 ]

		elseif strcmp(gen.type,'ROW2')
			countries = [ 20 21 23 24 28 31 32 33 34 35 38 39 41 43 44 45 49 52 53 54 55 56 62 64 66 68 69 71 72 73 75 76 77 78 79 80 ]

        elseif strcmp(gen.type,'SA_HV')
            countries = [ 1 2 3 4 6 7 8 9 10 12 14 15 21 24 26 28 38 42 49 51 57 58 61 62 70 72 74 ]

        elseif strcmp(gen.type,'ME_HV')
            countries = [ 1 2 4 ]

        elseif strcmp(gen.type,'ROW_HV')
            countries = [ 5 11 13 16 17 18 19 20 22 23 25 27 29 30 31 32 33 34 35 36 37 39 40 41 43 44 45 46 47 48 50 52 53 54 55 56 59 60 63 64 65 66 67 68 69 71 73 75 76 77 78 79 80 ]

        elseif strcmp(gen.type,'noME_SA_HV')
        	countries = [ 3 6 7 8 9 10 12 14 15 21 24 26 28 38 42 49 51 57 58 61 62 70 72 74 ]

        else
            countries=1:gen.('N');
        end
		
		% Keep only required data (positive exporters)
        sales_data=Brazil_data(1:gen.('G'),countries,:);
        sales_data_original = sales_data;
        pos_exporters = (sum(sum(sales_data,1)>0,2)>0);
        sales_data = (sales_data(:,:,pos_exporters==1));
        sales_data_original = sales_data;

        if gen.bootstrap == 1;
            rng('shuffle')
            sales_data = sales_data(:,:,(randsample(size(sales_data,3),size(sales_data,3),true)));
        end

    end


end

