function [ OUT ] = generate_destination_probabilities( sales_data,sim_data,display,names,plot_name,plot_title)
%generate_destination_probabilities generates export destination probabilities
%   Detailed explanation goes here

	% Actual Prob of Exporting
		products_sold = sum(sales_data(:,1:5,:)>0,1);
		country_sales = sort(squeeze(sum(products_sold > 0,2)));
		exporters = histc(country_sales,1:5);
		probability_actual = exporters./sum(exporters);

	% Probability under strict ordering
		exporters_dest = (squeeze(sum(products_sold > 0,3)))';
		probability_strict = exporters_dest./sum(exporters_dest);

	
	% Probability under balls and bins
		probability = exporters_dest./sum(exporters);

		n = numel(probability);
		combs = dec2bin(0:2^n-1).'-'0'; %'// each column is a combination of n values,
		%// where each value is either 0 or 1. A 1 value will represent an event
		%// that happens; a 0 value will represent an event that doesn't happen.
		result = NaN(1,n+1); %// preallocate
		for k = 0:n; %// number of events that happen
			ind = sum(combs,1)==k; %// combinations with exactly k 1's
			result(k+1) = sum(prod(...
				bsxfun(@times, probability(:), combs(:,ind)) + ... %// events that happen
				bsxfun(@times, 1-probability(:), ~combs(:,ind)) )); %// don't happen
		end

		probability_ind = result(2:6)./sum(result(2:6));

	%Simmulated Probability
		products_sold = sum(sim_data(:,1:5,:)>0,1);
		country_sales = sort(squeeze(sum(products_sold > 0,2)));
		probability_sim = histc(country_sales,1:5)./sum(country_sales>0,1)	;
		histc(country_sales,0:8);
		probability_sim = probability_sim./sum(probability_sim);


	PROBS = (sum(exporters)*[probability_actual probability_strict probability_ind'  probability_sim]);

	OUT = ([PROBS
			sum(PROBS)]);

	if display == 1
		for r = 1:(size(OUT,1)-1)
			fprintf('%1.0f\t%6.0f\t%6.0f\t%6.0f\t%6.0f\n',[r OUT(r,:)]);
		end
		r = size(OUT,1);
		fprintf('Total\t%6.0f\t%6.0f\t%6.0f\t%6.0f\n',[OUT(r,:)]);
	end
	
	fid = fopen(names, 'w');
	fprintf(fid,'tab: %s \n', names);
	for r = 1:(size(OUT,1)-1)
		fprintf(fid,'%1.0f\t%6.0f\t%6.0f\t%6.0f\t%6.0f\n',[r OUT(r,:)]);
	end
	r = size(OUT,1);
	fprintf(fid,'Total\t%6.0f\t%6.0f\t%6.0f\t%6.0f\n',[OUT(r,:)]);
	fclose(fid);

    f = figure;
    hb=bar(OUT(1:5,:)','stacked');
    colormap(gray)
    ylim([0 OUT(6,1)])
    Labels = {'Data','Strict Ordering','Independence','Simulation'};
    set(gca,'xticklabel',Labels) 
%    title (plot_title,'FontSize', 20);
    ylabel(['Number of Top 5 Destinations for ' plot_title]);
    l=legend({'1','2','3','4','5'},'Location', 'SouthEastOutside');
    v = get(l,'title');
    set(v,'string',sprintf('Number of\nDestinations'));
    print(f, '-depsc', strcat(plot_name,'.eps'));

end