function [ output_args ] = generate_moments( sales, moments )
%% Generates Moments from the data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set up dimensions and weights
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

G = size(sales,1);
N = size(sales,2);
J = size(sales,3);
if moments.geometric >= 2
    moments.geometric_w = moments.geometric_w(1:N)./sum(moments.geometric_w(1:N));
end
output_args =[];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Unused Moments
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if moments.AR ==1;
	% Unused
end

if moments.A == 1;
	% Unused
end

if moments.AP == 1;
	% Unused
end

if moments.B == 1;
	% Unused
end

if moments.CC == 1;
	%Unused
end

if moments.CO == 1;
	%Unused
end	
	
if moments.D == 1;
	% Unused
end

if moments.D3 == 1;
	% Unused
end

if moments.BB == 1;
	% Unused
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Between-Firm Sales Distributions
%% Ratio of 1st product sales for G product firms by Percentiles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if moments.AC == 1;
    
    products_bot = [1 2 4 7];
    products_top = [1 3 6 50];
    products_sold = sum(sales>0,1);
    
	for cc = 1:4

        indicator0 = (products_sold>=products_bot(cc) & products_sold<=products_top(cc) );
    
        sales1 = sales(1,:,:).*indicator0;
        
        if N == 1
            sales1_sort=sort(squeeze(sales1)','descend')';
        else
            sales1_sort=sort(squeeze(sales1)','descend');
        end
    
        counts = sum(sales1_sort>0,1);
        bins = [.95 .25 .5 .6 .7 .8 .85 .90 ];
        bins = [ .5 .25 .6 .7 .8 .85 .90 .95];

        i = repmat(1:N,size(bins,2),1);
        j = round((1-repmat(bins',1,N)).*repmat(counts,size(bins,2),1));
        j = max(j,1);

        try
            salespct = sales1_sort(sub2ind(size(sales1_sort),j,i));
            ratio50pct = salespct(2:size(bins,2),:)./repmat(salespct(1,:),(size(bins,2)-1),1);

            if moments.geometric == 1               % Average across all countries
                ratio50pct = nanmean(log(ratio50pct),2);	
            elseif moments.geometric >= 2           % Weighted Average across all countries
                weights = repmat(moments.geometric_w ,size(bins,2)-1,1);
                ratio50pct = nansum(weights.*log(ratio50pct),2); 
            else
                log(ratio50pct);
            end
        catch
           ratio50pct = i(1:(size(i,1)-1),1);
        end
        
        output_args = [output_args reshape(exp(ratio50pct),1,[]) 1];
        
    end

end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Within-Firm Sales Distributions
	% Firms that sell 2,4,8, etc
	% Ratio of sales between 1/2, 2/4, 4/8
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if moments.BA1 == 1;
	products_sold = sum(sales>0,1);
	product1  = sales( 1,:,:);
	product2  = sales( 2,:,:);
	product3  = sales( 3,:,:);
	product4  = sales( 4,:,:);
	product6  = sales( 6,:,:);
	
	% This and the other try/catch have to due with backwards compatability 
	% If it doesn't work out, we revert to defaults
	try
		if moments.BA1_alt==1
			bins = [.5];
		else
			bins = [.1 .25 .5 .75 .9];
		end
			
	catch
		bins = [.1 .25 .5 .75 .9];
	end
	indicator0 = (products_sold==1);
	
	
	% More than 2 products sold
	indicator1 = (products_sold==2  | products_sold==3);
	S1=sort(reshape(log(product2(indicator1)./product1(indicator1)),[],1,1),'ascend');
    try
		R1 = S1(max(1,ceil(bins*size(S1,1))),1);
    catch
		max(1,ceil(bins*size(S1,1)));
		R1 = bins' * 0;
    end	
	
	% More than 4 Products Sold
	indicator2 = (products_sold>=4  & products_sold<=6);
	S2=sort(reshape(log(product4(indicator2)./product1(indicator2)),[],1,1),'ascend');
 	S2b=sort(reshape(log(product3(indicator2)./product1(indicator2)),[],1,1),'ascend');
 	S2c=sort(reshape(log(product2(indicator2)./product1(indicator2)),[],1,1),'ascend');
    
    try
        R2 = S2(max(1,ceil(bins*size(S2,1))),1);
        R2b = S2b(max(1,ceil(bins*size(S2b,1))),1);
        R2c = S2c(max(1,ceil(bins*size(S2c,1))),1);
        
    catch
        R2 = bins' * 0;
        R2b = bins' * 0;
        R2c = bins' * 0;
    end
    
    % More than 6 products sold
    indicator3 = (products_sold>6 & products_sold<=50);
    S3=sort(reshape(log(product6(indicator3)./product1(indicator3)),[],1,1),'ascend');
    S3b=sort(reshape(log(product3(indicator3)./product1(indicator3)),[],1,1),'ascend');
    S3c=sort(reshape(log(product2(indicator3)./product1(indicator3)),[],1,1),'ascend');
    try
        R3 = S3(max(1,ceil(bins*size(S3,1))),1);
        R3b= S3b(max(1,ceil(bins*size(S3b,1))),1);
        R3c= S3c(max(1,ceil(bins*size(S3c,1))),1);
    catch
        R3 = bins' * 0;
        R3b = bins' * 0;
        R3c = bins' * 0;
    end

    momentBA1 =[R1 R2 R2b R2c R3 R3b R3c];

    output_args = [output_args reshape(exp(momentBA1),1,[]) 1];
    
    if moments.BA2 == 1;
		%unused
    end
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Exporter Scope
	% moments is based on the exporter scope within each destination, governed by
	% equation (29). We compute the proportion of simulated exporters md(4, ) that sell at least 2, 4, 8, 16 and
	% 32 products at a given destination d.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if moments.C == 1;

	if moments.BA1 ~= 1;
		products_sold = sum(sales>0,1);
	end
	
	product_bins = [2 4 6 8 12 16];
	noexporters = sum(products_sold>=1,3);		% Number of Exporters
	momentC = zeros(size(product_bins,2),N);

	for products_idx=1:size(product_bins,2)
		products=product_bins(products_idx);
		momentC(products_idx,:)=sum(products_sold>=products,3)./noexporters;
	end
 	momentC(momentC==0)=NaN;
	
	if moments.geometric == 1                   % Average across all countries
		momentC = nanmean(log(momentC),2);	
    elseif moments.geometric >= 2               % Weighted Average across all countries
        weights = repmat(moments.geometric_w ,size(product_bins,2),1);
        weights_denom = sum(weights.*(momentC>0),2);
        momentC = nansum(weights.*log(momentC),2)./weights_denom; 
	else
		momentC = log(momentC);
	end
	output_args = [output_args reshape(exp(momentC),1,[]) 1];
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Destination Strings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if moments.D2 == 1;
    if moments.BA1 ~= 1;
        products_sold = sum(sales>0,1);
    end

    Dest_string = zeros(25,1);
    Dest_string_info = zeros(25,5);
    Dest_string_info2 = zeros(25,5);
    i=0;
    
    if N >= 5
    	country_entry = squeeze(products_sold(:,1:5,:)>0)';
        for i1 = 0:1
            d1 = (country_entry(:,1) == i1);
            for i2 = 0:1
                d2 = (country_entry(:,2) == i2);
                for i3 = 0:1
                    d3 = (country_entry(:,3) == i3);
                    for i4 = 0:1
                        d4 = (country_entry(:,4) == i4);
                        for i5 = 0:1
                            i=i+1;
                            d5 = (country_entry(:,5) == i5);
                            Dest_string_info(i,:) = [i1 i2 i3 i4 i5];
                            Dest_string_info2(i,:) = [sum(d1) sum(d2) sum(d3) sum(d4) sum(d5)];
                            
                            Dest_string(i)=length(country_entry(d1 & d2 & d3 & d4 & (country_entry(:,5) == i5),:));
                        end 
                    end
                end
            end
        end
    end
    
    % For cases with 3 countries
    if N < 5
    	country_entry = squeeze(products_sold(:,1:3,:)>0)';
        for i1 = 0:1
            d1 = (country_entry(:,1) == i1);
            for i2 = 0:1
                d2 = (country_entry(:,2) == i2);
                for i3 = 0:1
                    d3 = (country_entry(:,3) == i3);
                    i=i+1;
                    Dest_string_info(i,:) = [i1 i2 i3 0 0 ];
                    Dest_string(i)=length(country_entry(d1 & d2 & d3));
                end
            end
        end
    end
    
    Dest_string(1) = 0; 
    if moments.display == 1;
        [Dest_string Dest_string_info Dest_string_info2]
    end
    Dest_string =(Dest_string./sum(Dest_string));
    output_args = [output_args reshape(Dest_string,1,[])];
    
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sales Ratios Between Countries
%     Ratio of Sales in second county to first, third to first, etc
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if moments.D4 == 1
	if moments.AR ==0;
		sales_df = squeeze(sum(sales,1))';
		m_d = sum(sales_df>0);
    end
    sales_df_nan=sales_df;
    sales_df_nan(sales_df_nan == 0) = NaN;  
    

    if N >= 5
        ratios = repmat(sales_df_nan(:,1),1,5)./sales_df_nan(:,2:6);
        count = sum(~isnan(ratios));
        
        ratios_sort=sort(ratios,'ascend');
        bins = [.95 .25 .5 .6 .7 .8 .85 .90 ];
        bins = [ .5 .25 .6 .7 .8 .85 .90 .95];
        
        i = repmat(1:5,size(bins,2),1);
        j = round((repmat(bins',1,5)).*repmat(count,size(bins,2),1));
        j = max(j,1);
    else
        ratios = repmat(sales_df_nan(:,1),1,(N-1))./sales_df_nan(:,2:N);
        count = sum(~isnan(ratios));
        
        ratios_sort=sort(ratios,'ascend');
        bins = [.95 .25 .5 .6 .7 .8 .85 .90 ];
        bins = [ .5 .25 .6 .7 .8 .85 .90 .95];
        
        i = repmat(1:(N-1),size(bins,2),1);
        j = round((repmat(bins',1,(N-1))).*repmat(count,size(bins,2),1));
        j = max(j,1);
    end


    ratiospct = ratios_sort(sub2ind(size(ratios_sort),j,i));
    ratio50pct = ratiospct(2:size(bins,2),:)./repmat(ratiospct(1,:),(size(bins,2)-1),1);
    ratio50pct = nanmean(log(ratio50pct),2);
    momentD4 = exp(ratio50pct);
    output_args = [output_args reshape(momentD4,1,[])];
    
end


if moments.display == 1;
	display(output_args)
end

output_args(isnan(output_args)) = 9;
output_args(isinf(output_args)) = 9;



end