% ----------------------------------------------------------------------------------------
% Code for "The extensive Margin of Exporting Products: A firm level Analysis"
% Arkolakis & Ganapati & Muendler
% ----------------------------------------------------------------------------------------
% Inner main routine for MSM
% Last Edited: 2004-08-02 // Sharat Ganapati
% ----------------------------------------------------------------------------------------

% ----------------------------------------------------------------------------------------
%% Initialize/Set up Folder Etc
% ----------------------------------------------------------------------------------------
gen.folder = strcat(datestr(now,'yyyymmdd-HHMMSS-'),int2str(floor(rand()*10)));
gen.use_run = strcat('Output/',gen.file,'/');
gen.use_dir = strcat('Output/',gen.file,'/',gen.folder,'/');

if exist(strcat('Output/',gen.file),'dir') > 0 & gen.bootstrap == 0 & o.randomize == 0
    exit
elseif exist(gen.use_dir,'dir')
	exit
end

mkdir(strcat('Output/',gen.file),gen.folder)
diary(strcat(gen.use_dir,'Log',gen.file,'.txt'));

% ----------------------------------------------------------------------------------------
%% Paramters not set earlier
% ----------------------------------------------------------------------------------------
gen.use_mean        = 0;        % Use for Means instead of Medians for getting Fd

o.phicountry        = 1;        % Is Phi for a country the same across destinations?
o.find_f1           = 0;        % Do we find fs1(1)? Otherwise lock it down

                                
moments.weighted    = 1;        % 0 = do not use weighting matrix
                                % 1 = use EKK weighting matrix
                                % 2 = use weighting matrix based on xW
                                %     caluclated using random samples
moments.geometric   = 2;        % 0 = use idependant moments
                                % 1 = use unweighted geometric moments
                                % 2 = use geometric moments weighted by no.
                                %     of exporting firms
                                % 3 = use use geometric moments weighted by
                                %     total country sales
moments.display     = 0;        % DISPLAY MOMENTS (FOR TESTING ONLY)

% ----------------------------------------------------------------------------------------
%% Micro Moments
% ----------------------------------------------------------------------------------------
moments.AC =1 ; % Ratio of 1st product sales for G product firms by Percentiles
if gen.sigma_xi == 0
	moments.BA1=1 ; % Ratio of sales between 1/2, 2/4, 4/8 for 2, 4, 6 product firms
	moments.BA1_alt=1 ; % Ratio of sales between 1/2, 2/4, 4/8 for 2, 4, 6 product firms
else
	moments.BA1=1 ; % Ratio of sales between 1/2, 2/4, 4/8 for 2, 4, 6 product firms
	moments.BA1_alt=0 ; % Ratio of sales between 1/2, 2/4, 4/8 for 2, 4, 6 product firms
end
moments.C  =1 ; % The fourth set of moments is based on the exporter scope within each destination,
if 	gen.sigma_c == 0
	moments.D2 =0 ; % Moments that are equivalent to the proportion of exporters to 1, 12, 123, 1345 etc 
	moments.D4 =0 ; % Ratio of sales of median exporters between destinations
else
	moments.D2 =1 ; % Moments that are equivalent to the proportion of exporters to 1, 12, 123, 1345 etc 
	moments.D4 =1 ; % Ratio of sales of median exporters between destinations
end

% ----------------------------------------------------------------------------------------
%% Set up monte carlo if so
% ----------------------------------------------------------------------------------------
xW = x0;
if gen.simulate == 1
   gen.('N') = o.('N'); 
end

% ----------------------------------------------------------------------------------------
%% Display
% ----------------------------------------------------------------------------------------
display(x0)
display(gen)
display(moments)
display(o)

% ----------------------------------------------------------------------------------------
%% Set Up Sources
% ----------------------------------------------------------------------------------------
gen.type = 'OTHER';
genA=gen;
genB=gen;

if      strcmp(gen.joint_type,'mfged')
    genA.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genB.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genA.type   = 'SA' ;
    genB.type   = 'ROW';
elseif  strcmp(gen.joint_type,'mfged_adj')
    genA.source   = 'Brazil_Matlab_80co_100pr_mfged_adj_count.mat';
    genB.source   = 'Brazil_Matlab_80co_100pr_mfged_adj_count.mat';
    genA.type   = 'SA' ;
    genB.type   = 'ROW';
elseif  strcmp(gen.joint_type,'mfged_highvol')
    genA.source   = 'Brazil_Matlab_40co_100pr_mfged_highvol_count.mat';
    genB.source   = 'Brazil_Matlab_40co_100pr_mfged_highvol_count.mat';
    genA.type   = 'SA_HV' ;
    genB.type   = 'ROW_HV';
elseif  strcmp(gen.joint_type,'mfged_hs8')
    genA.source   = 'Brazil_Matlab_40co_100pr_mfged_hs8_count.mat';
    genB.source   = 'Brazil_Matlab_40co_100pr_mfged_hs8_count.mat';
    genA.type   = 'SA' ;
    genB.type   = 'ROW';
elseif strcmp(gen.joint_type,'mfged-noARUS')
    genA.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genB.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genA.type   = 'SA_noAR' ;
    genB.type   = 'ROW_noUS';
elseif  strcmp(gen.joint_type,'mfged_merc_double')
    genA.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genB.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genA.type   = 'ME' ;
    genB.type   = 'noME';
elseif strcmp(gen.joint_type,'mfged_mercsa_double')
    genA.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genB.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';
    genA.type   = 'ME' ;
    genB.type   = 'noME_SA';
else
    exit
end



% ----------------------------------------------------------------------------------------
%% Get Sales Data (Either through Simulation or from Brazil)
% ----------------------------------------------------------------------------------------
[sales_dataA,sales_data_originalA] = generate_data_wrapper( genA, o);
[sales_dataB,sales_data_originalB] = generate_data_wrapper( genB, o);

display(size(sales_dataA))
display(size(sales_dataB))
display(size(sales_data_originalA))
display(size(sales_data_originalB))
    
% ----------------------------------------------------------------------------------------
%% Generate Moments
% Alternate between methods of weighting
% ----------------------------------------------------------------------------------------

momentsA=moments;
if moments.geometric == 2
    firms_sells             = sum(sum(sales_dataA>0,1)>0,3);
    momentsA.geometric_w     = firms_sells./sum(firms_sells,2);
elseif moments.geometric == 3
    total_sales             = nansum(sum(sales_dataA,1),3);
    momentsA.geometric_w     = total_sales./sum(total_sales,2);
end

momentsB=moments;
if moments.geometric == 2
    firms_sells             = sum(sum(sales_dataB>0,1)>0,3);
    momentsB.geometric_w     = firms_sells./sum(firms_sells,2);
elseif moments.geometric == 3
    total_sales             = nansum(sum(sales_dataB,1),3);
    momentsB.geometric_w     = total_sales./sum(total_sales,2);
end

moment_dataA = generate_moments(sort(sales_dataA,'descend'), momentsA);
moment_dataB = generate_moments(sort(sales_dataB,'descend'), momentsB);

moment_data_originalA = generate_moments(sort(sales_data_originalA,'descend'), momentsA);
moment_data_originalB = generate_moments(sort(sales_data_originalB,'descend'), momentsB);

size(moment_dataA)
size(moment_dataB)
display([moment_dataA(1:size(moment_dataA,2))' moment_dataB(1:size(moment_dataA,2))'])

% ----------------------------------------------------------------------------------------
%% Recover FD
% Depreciated Function
% ----------------------------------------------------------------------------------------
fd_recoveredA = 1;
fd_recoveredB = 1;


% ----------------------------------------------------------------------------------------
%% For Simulation Method of Moments
% ----------------------------------------------------------------------------------------
display('Simulating Draws')

o.('J')     = gen.('J');        % Number of Brazilian SImulated Firms
o.('G')     = gen.('G');        % Maximum Number of Products Sold by a Firm

% 10188 exporters overall;
if exist('Export_ratio') == 0
	Export_ratio = .03;
end

Overall_exporters = 10188;

% A Does South America
Md_dataA = sum(squeeze(sum(sales_dataA,1))'>0)';   % Firms  Exporting to a given country
Md_dataA = Md_dataA(1:min(size(sales_dataA,2),o.('N')));

Export_ratioA= Md_dataA/(Overall_exporters/Export_ratio);
oA=o;
oA.('N')=min(size(sales_dataA,2),o.('N'));

make_simulatedA = generate_simulation( fd_recoveredA, Md_dataA,Export_ratioA,oA );
if oA.('N') >= 5
	generate_strings_display(sales_dataA, make_simulatedA , x0)
end


% B Does ROW
Md_dataB = sum(squeeze(sum(sales_dataB,1))'>0)';    % Firms  Exporting to a given country
Md_dataB = Md_dataB(1:o.('N'));
Export_ratioB= Md_dataB/(Overall_exporters/Export_ratio);


make_simulatedB = generate_simulation( fd_recoveredB, Md_dataB,Export_ratioB,o );
if o.('N') >= 5
	generate_strings_display(sales_dataB, make_simulatedB , x0)
end

display([Md_dataA])
display([Md_dataB])

% ----------------------------------------------------------------------------------------
%% Generate Moments
% ----------------------------------------------------------------------------------------

moment_simulatedA = @(x) generate_moments(1   *sort(make_simulatedA(x(1:6)),'descend'), momentsA);
moment_simulatedB = @(x) generate_moments(1   *sort(make_simulatedB(x(1:6)),'descend'), momentsB);

if gen.same_delta == 0
    g             = @(x) [(moment_simulatedA([x(1) x(2) x(3) x(4) x(5) 0]) - moment_dataA) (moment_simulatedB([x(6) x(2) x(3) x(4) x(5) 0]) - moment_dataB)];
    LB = [-2,1,1,0,0.2,-2];
    UB = [0 ,6,3,6,1.6, 0];
else
    g             = @(x) [(moment_simulatedA([x(1) x(2) x(3) x(4) x(5) 0]) - moment_dataA) (moment_simulatedB([x(1) x(2) x(3) x(4) x(5) 0]) - moment_dataB)];
    LB = [-2,1,1,0,0.2,x0(6)];
    UB = [0 ,6,3,6,1.6,x0(6)];
    x0(6)=x0(1);
end

if gen.sigma_c == 0
	LB(5) = 0;
	UB(5) = 0;
	x0(5) = 0;
end
if gen.sigma_xi == 0
	LB(3) = 0;
	UB(3) = 0;
	x0(3) = 0;
end

% ----------------------------------------------------------------------------------------
% Diagnostics
try
	[moment_simulatedA([x0(1) x0(2) x0(3) x0(4) x0(5) 0])' moment_simulatedB([x0(6) x0(2) x0(3) x0(4) x0(5) 0])']
catch
end
% ----------------------------------------------------------------------------------------

% ----------------------------------------------------------------------------------------
%% Weighting Matrix / Criterion Fct
% ----------------------------------------------------------------------------------------
x0=x0(1:6)
W_start          = generate_weights_wrapper_joint( momentsA,momentsB,moment_data_originalA,moment_data_originalB,sales_data_originalA,sales_data_originalB,gen.use_run);
criterion_fct    = @(x) criterion_fct_W(W_start,g(x));
criterion_fct    = @(x) criterion_fct([x(1) x(2) x(3) x(4) x(5) x(6)]);
constraint_checker =  @(x) check_constraints(x0);

% ----------------------------------------------------------------------------------------
%% Initialize and Get Timings
% ----------------------------------------------------------------------------------------
tic
display(LB)
display(UB)
display(x0)
display(constraint_checker(x0))
display(criterion_fct(x0))
save(strcat(gen.use_dir,gen.file,'x0.mat'), 'x0')
toc
save(strcat(gen.use_dir,gen.file,'start.mat'), 'x*' , 'moments','gen','o')
close

% ----------------------------------------------------------------------------------------
%% First Stage Get Results
% ----------------------------------------------------------------------------------------

if o.search_sa == 0
    x1 = x0;
    save(strcat(gen.use_dir,gen.file,'x1.mat'), 'x*')
    display(x1)

    [x2,~,~,~] = fminsearchcon(criterion_fct,x1,LB,UB,[],[],       constraint_checker,optimset('Display','iter-detailed'));
    save(strcat(gen.use_dir,gen.file,'x2.mat'), 'x*')
    display(x2)

    [x3,~,~,~] = fminsearchcon(criterion_fct,x2,LB,UB,[],[],       constraint_checker,optimset('Display','iter-detailed'));
    save(strcat(gen.use_dir,gen.file,'x3.mat'), 'x*')
    display(x3)

    [x4 ,~,~,~] = patternsearch(criterion_fct,x3,[],[],[],[],LB,UB,constraint_checker,psoptimset('Display','iter','InitialMeshSize',.125,'PollMethod','MADSPositiveBasis2N','Cache','on','MaxFunEvals',50,'TolX',.05));
    save(strcat(gen.use_dir,gen.file,'x4.mat' ), 'x*')
	display(x4)
    
elseif o.search_sa == 1

elseif o.search_sa == 2

elseif o.search_sa == 3

end

% ----------------------------------------------------------------------------------------
%% POST minimization analysis
% ----------------------------------------------------------------------------------------
x0A = [x0(1) x0(2) x0(3) x0(4) x0(5) 0];
x0B = [x0(6) x0(2) x0(3) x0(4) x0(5) 0];

if gen.same_delta == 0
    x4A = [x4(1) x4(2) x4(3) x4(4) x4(5) 0];
    x4B = [x4(6) x4(2) x4(3) x4(4) x4(5) 0];
else
    x4A = [x4(1) x4(2) x4(3) x4(4) x4(5) 0];
    x4B = [x4(1) x4(2) x4(3) x4(4) x4(5) 0];
end

display([criterion_fct(x0) criterion_fct(x2) criterion_fct(x4)])
ffinal = criterion_fct(x4);
save(strcat(gen.use_dir,gen.file,'end.mat'), 'x*' , 'moments*','gen*','o','ffinal')

echo off

fprintf('x0:\t %.4f   %.4f   %.4f   %.4f   %.4f   %.4f\n'  ,x0);
fprintf('x2:\t %.4f   %.4f   %.4f   %.4f   %.4f   %.4f\n'  ,x2);
fprintf('x4:\t %.4f   %.4f   %.4f   %.4f   %.4f   %.4f\n'  ,x4);

check_constraints_all(x0A)
check_constraints_all(x0B)

check_constraints_all(x4A)
check_constraints_all(x4B)

try
	display([moment_simulatedA(x0A)' moment_simulatedA(x4A)' moment_dataA' moment_simulatedB(x0B)' moment_simulatedB(x4B)' moment_dataB'])
catch
	display([moment_simulatedA(x0A)' moment_simulatedA(x4A)' moment_dataA'])
	display([moment_simulatedB(x0B)' moment_simulatedB(x4A)' moment_dataB'])
end

if oA.('N') >= 5
	generate_strings_display(sales_dataA, make_simulatedA , x4A)
end

if o.('N')  >= 5
	generate_strings_display(sales_dataB, make_simulatedB , x4B)
end

% ----------------------------------------------------------------------------------------
%% Plot Data
% ----------------------------------------------------------------------------------------

if gen.bootstrap == 0 & o.randomize == 0
	plot_optimality(x4,x2,x0,criterion_fct,strcat('Optimized-',gen.file),gen.use_dir);

	namesA = {'AR','UY','CL','PY','BO'};
	namesB = {'US','DE','IT','UK','SP'};
	
	plot_exporter_size    ( sales_dataA,'ATruth-exporter-size'  	,gen.use_dir, namesA);
	plot_exporter_scope   ( sales_dataA,'ATruth-exporter-scope' 	,gen.use_dir, namesA);
	plot_totalsales_prod  ( sales_dataA,'ATruth-firm-sales'        	,gen.use_dir, namesA);
	plot_within_firm_sales( sales_dataA,'ATruth-within-firm-sales' 	,gen.use_dir, namesA);
	plot_exporter_scale   ( sales_dataA,'ATruth-exporter-scale'  	,gen.use_dir, namesA);

	plot_exporter_size    ( sales_dataB,'BTruth-exporter-size' 		,gen.use_dir, namesB);
	plot_exporter_scope   ( sales_dataB,'BTruth-exporter-scope' 	,gen.use_dir, namesB);
	plot_totalsales_prod  ( sales_dataB,'BTruth-firm-sales' 		,gen.use_dir, namesB);
	plot_within_firm_sales( sales_dataB,'BTruth-within-firm-sales' 	,gen.use_dir, namesB);
	plot_exporter_scale   ( sales_dataB,'BTruth-exporter-scale'		,gen.use_dir, namesB);
	
	sim_data = sort(make_simulatedA(x4A),'descend');
	plot_exporter_size    ( sim_data,'ASim-exporter-size' 			,gen.use_dir, namesA);
	plot_exporter_scope   ( sim_data,'ASim-exporter-scope' 			,gen.use_dir, namesA);
	plot_totalsales_prod  ( sim_data,'ASim-firm-sales' 				,gen.use_dir, namesA);
	plot_within_firm_sales( sim_data,'ASim-within-firm-sales' 		,gen.use_dir, namesA);
	plot_exporter_scale   ( sim_data,'ASim-exporter-scale'			,gen.use_dir, namesA);
	
	sim_data = sort(make_simulatedB(x4B),'descend');
	plot_exporter_size    ( sim_data,'BSim-exporter-size' 			,gen.use_dir, namesB);
	plot_exporter_scope   ( sim_data,'BSim-exporter-scope' 			,gen.use_dir, namesB);
	plot_totalsales_prod  ( sim_data,'BSim-firm-sales' 				,gen.use_dir, namesB);
	plot_within_firm_sales( sim_data,'BSim-within-firm-sales' 		,gen.use_dir, namesB);
	plot_exporter_scale   ( sim_data,'BSim-exporter-scale'			,gen.use_dir, namesB);
end

diary('off');

break;
return;
