% ----------------------------------------------------------------------------------------
% Code for "The extensive Margin of Exporting Products: A firm level
% Analysis" - Arkolakis & Muendler (and now Ganapati)
% ----------------------------------------------------------------------------------------
% Setup Program for Joint Estimation
% Sharat Ganapati
% Edited: 2004-06-14
% ----------------------------------------------------------------------------------------

% ----------------------------------------------------------------------------------------
% Calls main_v20_joint
% Notes:
% 	Parameters are delta, theta_tilda, sigma_xi, alpha, sigma_c, delta2
%	This is wrapped up in x0
% 	main_v20_joint outputs x4, which is the final result (Omega_hat in the paper)
% ----------------------------------------------------------------------------------------

% ----------------------------------------------------------------------------------------
% Initialize
% ----------------------------------------------------------------------------------------
clear all
format compact
echo on
clc
addpath('Plot_Routines')

% ----------------------------------------------------------------------------------------
% Set Up radomized values
% ----------------------------------------------------------------------------------------
rng('shuffle')
which = -1
%while ismember(which,[-1 6 7 8 9 10])
while ismember(which,[-1 0 1 2 3 4 5 6 7 8 9 11])
	w     = rand
	which = floor(w*12)
end

bs_rnd= floor(rand*2)
%bs_rnd = 1

% ----------------------------------------------------------------------------------------
% Random Starting Values
% (Not used in this iteration, we force initialization constant)
% This is helpful in montecarlo for example.
% ----------------------------------------------------------------------------------------
xstart           = [-0.9010   1.3520   1.8645   2.0511   0.8330   -0.9010   -0.9010];
x0 = xstart.*[(rand(1,5)+.5) 1 1];
while max(check_constraints(x0))>0
    x0 = xstart.*[(rand(1,5)+.5) 1 1];
end
x0
check_constraints(x0)

% ----------------------------------------------------------------------------------------
% Initialization Values
% ----------------------------------------------------------------------------------------
gen.('J')           = 1000000;  % Number of Simulated Braziling Firms
gen.('N')           = 32;       % Number of Countries
gen.('G')           = 50;       % Number of Product Lines
o.do__EN            = 0;
o.do_EKK            = 1 ;       % Use Eaton-Kortum-Kramatz Model
o.('N')             = 6 ;       % Number of SIMULATED COUNTRIES
o.search_sa         = 0;        % 0 = do neadler meade
                                % 1 = do simmulated annealing
                                % 2 = do stepwise neadler meade
gen.bootstrap       = bs_rnd;   % Use for Boostrapping SE
o.randomize         = bs_rnd;   % Radomize
gen.simulate        = 0;        % Monte Carlo Simulation

% ----------------------------------------------------------------------------------------
% Do Monte Carlo Estimation Forcer
% ----------------------------------------------------------------------------------------
if gen.simulate  == 1
    o.randomize = 1;
    which = 0;
end

% ----------------------------------------------------------------------------------------
% Do Boostrap Randomizer
% ----------------------------------------------------------------------------------------
if bs_rnd == 0
    bs_suffix = ''
elseif bs_rnd == 1
	bs_suffix = '-BS'
end

% ----------------------------------------------------------------------------------------
% Run Setup
% ----------------------------------------------------------------------------------------


if which == 0
	% ----------------------------------------------------------------------------------------
	% Main Specification
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-mfged-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 1
	% ----------------------------------------------------------------------------------------
	% No market access shocks
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-mfged-noC-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 0;
	gen.sigma_xi = 1;

elseif which == 2
	% ----------------------------------------------------------------------------------------
	% No product Appeal Shocks 
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-mfged-noX-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 0;
	
elseif which == 3
	% ----------------------------------------------------------------------------------------
	% No shocks whatsoever
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-mfged-noCX-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c = 0;
	gen.sigma_xi = 0;
	
elseif which == 4
	% ----------------------------------------------------------------------------------------
	% Adjusted Manufacturing Sample
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged_adj';
    gen.file       = strcat('A-W1G2-mfged_adj-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -0.9820    1.8096    1.9383    1.6641    0.6589     -0.9820         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 5
	% ----------------------------------------------------------------------------------------
	% High Volume Manufacturing Sample
	% ----------------------------------------------------------------------------------------
    gen.joint_type = 'mfged_highvol';
    gen.same_delta = 0;
    gen.('N')      = 30;
    gen.file       = strcat('A-W1G2-mfged_highvol-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1106    1.8735    2.1480    1.7691    0.8605     -1.1106         0]		
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 6
	% ----------------------------------------------------------------------------------------
	% Using HS8 Data
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged_hs8';
    gen.file       = strcat('A-W1G2-mfged_hs8-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;

elseif which == 7
	% ----------------------------------------------------------------------------------------
	% Main Specification with 10% Cutoff
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-mfged_10pct-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	Export_ratio = .10;
	
elseif which == 8
	% ----------------------------------------------------------------------------------------
	% Omitting the USA/Argentina
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged-noARUS';
    gen.file       = strcat('A-W1G2-mfged-noARUS-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 9
	% ----------------------------------------------------------------------------------------
	% Compare Mercosur Within LAC
	% ----------------------------------------------------------------------------------------
    gen.same_delta      = 0;
    gen.joint_type = 'mfged_merc_double';
    gen.file       = strcat('A-W1G2-mfged_merc_double-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 10
	% ----------------------------------------------------------------------------------------
	% Compare Mercosur with non-Mercosur
	% ----------------------------------------------------------------------------------------
    gen.joint_type = 'mfged_mercsa_double';
    gen.same_delta      = 0;
    gen.file       = strcat('A-W1G2-mfged_mercsa_double-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
	
elseif which == 11
	% ----------------------------------------------------------------------------------------
	%
	% ----------------------------------------------------------------------------------------
	gen.simulate  		= 1;
    o.randomize 		= 1;
    gen.same_delta      = 0;
    gen.joint_type = 'mfged';
    gen.file       = strcat('A-W1G2-simulate-NM-1000000f-32c-1s-joint-EKK2',bs_suffix);
	x0 = 	[   -1.1133    1.8959    1.8975    1.7803    0.6158   -1.1133         0]
	gen.sigma_c  = 1;
	gen.sigma_xi = 1;
end


%x0A = x0
%x0 = x0A.*[(rand(1,7)/5+.9)];
%while max(check_constraints(x0))>0
%    x0 = x0A.*[(rand(1,7)/5+.9)];
%end
%x0

% ----------------------------------------------------------------------------------------
% Call main program
% ----------------------------------------------------------------------------------------

main_v20_joint_ZA


% M; 10% cutoff
% O; Random start
% O is trial run for Mecosur/Non Mercosur
% P is final run for it.
% Q is a triple run for MERC
% R is a triple run with better start values.
% S is triple and ALL start
% T has the "double" NM method used
% U; cleaned method
% V; Simulated annealing / Use Multiple Starts / Use to Get best starting vals / Some Neadler Meade
% W; Less-Random Starts; Add BB
% X; Uses "L" start values. 
% Y; Get rid of BB starts.
% Z; fixed country strings; should be final run for v8 draft.
% ZA: shut down sigma_c and sigma_xi repective