% ----------------------------------------------------------------------------------------
% Make Plots for New Version of the Paper
% ----------------------------------------------------------------------------------------

clear
clc
close all

root =  '/gpfs/home/fas/arkolakis/sg596/2013_Multiproducts/'
addpath('EstimationSMM-v6-ratios/Plot_Routines')
addpath([root 'EstimationSMM-v6-ratios/Plot_Routines'])

o = 1;
gen.variance        = 1;
gen.simulate        = 0;
gen.bootstrap       = 0;
gen.('N')           = 32;       % Number of Countries
gen.('G')           = 50;       % Number of Product Lines
gen.('J')           = 1000000;
gen.use_dir         = [root '/Results/Plots/'];
gen.use_dir_tables  = [root '/Results/Tables/'];
gen.source = 'Brazil_Matlab_80co_100pr_mfged_count.mat';

x4 = 	[   -1.1729    1.8443    1.8882    1.7331    0.5283   -0.9023        0]

genA=gen;
genB=gen;
genC=gen;
genD=gen;
genE=gen;
genF=gen;

genA.type   = 'SA' ;
genB.type   = 'ROW';
genC.type   = 'OTHER';
genD.type   = 'NA';
genE.type   = 'EU';
genF.type   = 'ROW2';

mkdir(gen.use_dir )
mkdir(gen.use_dir_tables )

% ----------------------------------------------------------------------------------------
% Use Real Data make plots for A B C
% ----------------------------------------------------------------------------------------
[sales_dataA,~] = generate_data_wrapper( genA, o);
[sales_dataB,~] = generate_data_wrapper( genB, o);
[sales_dataC,~] = generate_data_wrapper( genC, o);
[sales_dataD,~] = generate_data_wrapper( genD, o);
[sales_dataE,~] = generate_data_wrapper( genE, o);
[sales_dataF,~] = generate_data_wrapper( genF, o);

size(sales_dataA)
size(sales_dataB)
size(sales_dataC)
size(sales_dataD)
size(sales_dataE)
size(sales_dataF)

nameA = {'ARG','URG','CHL','PRY','BOL'};
nameB = {'USA','GER','ITA','UK ','SPA'};
nameC = {'AR','UY','US','CL','PY'};
nameA_full = {'Argentina','Uruguay','Chile','Paraguay','Bolivia'}
nameB_full = {'USA','Germany','Italy','United Kingdom','Spain'}
nameC_full = {'Argentina','Uruguay','USA','Chile','Paraguay','Bolivia'}

% ----------------------------------------------------------------------------------------
% Simulate Data
% ----------------------------------------------------------------------------------------
gen.simulate 		= 1;
gen.phicountry      = 1;
gen.do_EKK 			= 1;
gen.do__EN 			= 0;
gen.('N')           = 6;       % Number of Countries
gen.randomize 		= 0;

% 10188 exporters overall;
Export_ratio = .03;
Overall_exporters = 10188;
x4A = [x4(1) x4(2) x4(3) x4(4) x4(5) 0];
x4B = [x4(6) x4(2) x4(3) x4(4) x4(5) 0];

Md_dataA = sum(squeeze(sum(sales_dataA,1))'>0)';   % Firms  Exporting to a given country
Md_dataA = Md_dataA(1:min(size(sales_dataA,2),gen.('N')));

Md_dataB = sum(squeeze(sum(sales_dataB,1))'>0)';    % Firms  Exporting to a given country
Md_dataB = Md_dataB(1:gen.('N'));

Md_dataC = sum(squeeze(sum(sales_dataC,1))'>0)';    % Firms  Exporting to a given country
Md_dataC = Md_dataC(1:gen.('N'));

Export_ratioA= Md_dataA/(Overall_exporters/Export_ratio);
Export_ratioB= Md_dataB/(Overall_exporters/Export_ratio);
Export_ratioC= Md_dataC/(Overall_exporters/Export_ratio);

make_simulatedA = generate_simulation( ones(size(Md_dataA)), Md_dataA,Export_ratioA,gen );
make_simulatedB = generate_simulation( ones(size(Md_dataB)), Md_dataB,Export_ratioB,gen );
make_simulatedC = generate_simulation( ones(size(Md_dataC)), Md_dataC,Export_ratioC,gen );

generate_strings_display(sales_dataA, make_simulatedA , x4A)
generate_strings_display(sales_dataB, make_simulatedB , x4B)
generate_strings_display(sales_dataC, make_simulatedC , x4B)

display([Md_dataA])
display([Md_dataB])
display([Md_dataC])

	sim_dataA = sort(make_simulatedA(x4A),'descend');
	sim_dataB = sort(make_simulatedB(x4B),'descend');

% For C data; combine A+B to make C; (Ie slip in the USA to replace Bolivia)
	sim_dataC(:,[1 2 4 5],:)=sim_dataA(:,1:4,:);
	size(sim_dataA(:,1,:))
	size(sim_dataB(:,1,:),3)
	sim_dataC(:,3,1:size(sim_dataB(:,1,:),3))        =sim_dataB(:,1,:);

% LAC Destination String Sample
	generate_strings_latex( sales_dataA,nameA,gen.use_dir_tables,'moments-exporter-strings-LAC' )

% ROW Destination String Sample
	generate_strings_latex( sales_dataB,nameB,gen.use_dir_tables,'moments-exporter-strings-ROW' )

% Data-Only Plots
	for i = 1:5
		plot_within_firm_sales( sales_dataA,'within-firm-sales-data-' 	,gen.use_dir, nameA_full{i},i);
		plot_within_firm_sales( sales_dataB,'within-firm-sales-data-' 	,gen.use_dir, nameB_full{i},1);
	end

    names_comp = {'Latin America and Caribbean','Rest of World'};
    plot_exporter_scope_2   ( sales_dataA,sales_dataB,1,1,'exporter-scope-data',gen.use_dir,names_comp );

	names_comp = {'Latin America and Caribbean','Rest of World','Linear Fit'};
    plot_totalsales_prod_2_alt  ( sales_dataA,sales_dataB,1,1,'firm-sales-data'    ,gen.use_dir,names_comp);

% Joint Data and Simulated Plots
	names = {'Argentina'}
	plot_within_firm_sales_2( sales_dataA,sim_dataA,'within-firm-sales-overlay-' 		,gen.use_dir, names);

    names_comp = {'Latin America and Caribbean - Data','Latin America and Caribbean - Simulated','Rest of World - Data','Rest of World - Simulated'};
    plot_exporter_scope_2   ( sales_dataA,sales_dataB,sim_dataA,sim_dataB,'exporter-scope-overlay',gen.use_dir,names_comp );
    
    names_comp = {'Latin America and Caribbean','North America','European Union','Rest of World'};
    plot_totalsales_prod_2_regions   ( sales_dataA,sales_dataD,sales_dataE,sales_dataF,'firm-sales-regions',gen.use_dir,names_comp );
    
	names_comp = {'Latin America and Caribbean - Data','Latin America and Caribbean - Simulated','Rest of World - Data','Rest of World - Simulated'};
    plot_totalsales_prod_2_alt  ( sales_dataA,sales_dataB,sim_dataA,sim_dataB,'firm-sales-overlay'    ,gen.use_dir,names_comp);

	names = {'Data','Simulated'};
    plot_exporter_size_2    ( sales_dataC,sales_dataC,sim_dataC,sim_dataC,'exporter-size-overlay'		,gen.use_dir, names);


break


% ----------------------------------------------------------------------------------------
% Run Diagnostics
% ----------------------------------------------------------------------------------------
% Re-simulated C Data using x4A for ALL destinations
	sim_dataCx = sort(make_simulatedC(x4A),'descend');

% Print out tab:firm-export-destinations for top 6 destinations
	fid = fopen([gen.use_dir_tables 'Table_firm-export-destinations' '.txt'], 'w');
	fprintf(fid,'tab:firm-export-destinations\n\n')
	fprintf(fid,'Destination\tExporters\t\tPercent\n')
	for i=1:size(Md_dataC,1)
		fprintf(fid,'%s\t%5.0f\t\t%2.0f%%\n',nameC_full{i},Md_dataC(i) ,100*Md_dataC(i)/size(sales_dataC,3))
	end
	fclose(fid);

% Print out tab:tab:firm-export-counts-X	
	generate_destination_probabilities( sales_dataA,sim_dataA ,1, [gen.use_dir_tables,'Table_','firm-export-counts-A.txt'] , [gen.use_dir,'firm-export-counts-A'] , 'Exporters to South America') ;
	generate_destination_probabilities( sales_dataB,sim_dataB ,1, [gen.use_dir_tables,'Table_','firm-export-counts-B.txt'] , [gen.use_dir,'firm-export-counts-B'] , 'Exporters to Rest of World') ;
	generate_destination_probabilities( sales_dataC,sim_dataCx,1, [gen.use_dir_tables,'Table_','firm-export-counts-C.txt'] , [gen.use_dir,'firm-export-counts-C'] , 'Exporters') ;



% Get firm size vs scope elasticities
    [generate_elasticity(sales_dataA) generate_elasticity(sim_dataA)
     generate_elasticity(sales_dataB)  generate_elasticity(sim_dataB)
     generate_elasticity(sales_dataC)  generate_elasticity(sim_dataC)]
     
	fid = fopen([gen.use_dir_tables 'Table_elasticities' '.txt'], 'w');
	fprintf(fid,'tab:firm-scope-size-elasticity\n\n');
	fprintf(fid,'Sample              \tData\tSimulated\n');
	fprintf(fid,'%s\t%5.2f\t%5.2f\n','South America Sample',generate_elasticity(sales_dataA),generate_elasticity(sim_dataA));
	fprintf(fid,'%s\t%5.2f\t%5.2f\n','Rest of World Sample',generate_elasticity(sales_dataB),generate_elasticity(sim_dataB));
	fprintf(fid,'%s\t%5.2f\t%5.2f\n','Combined Sample     ',generate_elasticity(sales_dataC),generate_elasticity(sim_dataC));
	fclose(fid);


for i = 1:2

	if i == 1
		d = sales_data_real;
	else
		d = sales_data_sim;
	end
	
	products = squeeze(sum(d(:,1,:)>0,1));
	sales    = squeeze(sum(d(:,1,:),1));
	best_sales=squeeze((d(1,1,:)));
	mean_sales=sales./products;

	corr(products(products>0),sales(products>0))
	corr(products(products>0),best_sales(products>0))
	corr(products(products>0),mean_sales(products>0))
end



