function [ output_args ] = plot_within_firm_sales( sales,name,folder,country_name,country)
%plot_within_firm_sales Plot Sales Distribution from Sales of specified Country

	specs = {' ok','-dk','-+k','-xk','-sk','--ok','-pk','-ok','-ok','--ok'};

	products_sold = sum(sales>0);
	N = size(sales,2);
    
	prod_range =   [1 2 5  9 17 ];
    prod_rangeUB = [1 4 8 16 32 ];
    
	x = 1;
	f=figure;
    
	for total_prods  = 1:size(prod_range,2);

        prod_range(total_prods);
        indicator = (products_sold>=prod_range(total_prods)) & (products_sold<=prod_rangeUB(total_prods));
		withinfirmdist = zeros(prod_range(total_prods),N);

		for rank  = 1:prod_rangeUB(total_prods);
            rank;
   			withinfirmdist(rank,:) = nansum(sales( rank,:,:).*indicator,3)./sum(indicator,3);
        end
        
        
        if total_prods==1
            loglog((1:prod_rangeUB(total_prods)),(withinfirmdist(:,country)),specs{x})
        else
            hold on;
            loglog((1:prod_rangeUB(total_prods)),(withinfirmdist(:,country)),specs{x})
            hold off; 
        end
        
		x = x+1;
	end


	% X-Axis
    set(gca,'XTick',[1 2 4 8 16 32]) 
	xlim([1 50])
	xlabel('Product Rank within Firm (HS 6-digit)','FontSize',14);

	% Y-Axis
    set(gca,'YTick',[1 100 10000 1000000 ]) 
    yt = get(gca,'YTick');
	set(gca,'YTickLabel', sprintf('%.0f|',yt))
	set(gca,'YTickLabel',{'1','100','10,000','1,000,000'})
	set(gca,'XGrid','off','YGrid','off','Box','off')
	ylabel('Mean Sales (US$)','FontSize',14);
	
	% Title
%	title ({strcat('Brazil to: ',names{country}),name},'FontSize', 20);
	
	% Legend
    B = {'G=1','G \in [2,4]','G \in [5,8]','G \in [9,16]','G \in [17,32]'};
	l=legend(B,'Location', 'NorthEast');
	v = get(l,'title');
	set(v,'string','Exporter Scope')
	htitle = get(l,'Title');
	set(htitle,'String','Exporter Scope')
	
	% Output
	file_name =strcat(folder,name,country_name,'.eps');
	print(f, '-depsc', file_name)
	
	fprintf('\tGenerated Sales Distribution for: %s\n',country_name)
	fprintf('\t\tSaved at: %s\n\n',file_name)

end
