%Arkolakis and Muendler 2010.
%counterfactuals. Program based on codes developed by
%Robert Dekle, Jonathan Eaton, Samuel Kortum
%for Unbalanced Trade, NBER Working Paper 13035

%Data for 57 plus Rest of the World (ROW) countries, see Arkolakis and Muendler 2010 for details
%Trade shares constructed by trade data

%Program computes changes in the new equilibrium.
close all
clear all
clc
echo off
root =  '/gpfs/home/fas/arkolakis/sg596/2013_Multiproducts/'


%-------------
%Loading data
%------------
%load trade_04.m % Bilateral trade in manufactures from United Nation Statistics Division
%load catb_04.m  % Current Account and balances on goods and services from IMF
%load gdp_04.m   % GDP from World Bank

trade00 =csvread('trade_00r2.csv');
gdp00   =csvread('gdp_00r2.csv');
catb00  =csvread('catb_00r2.csv');
absorp00=csvread('mfab_00r2.csv');

%----------
%Parameters
%----------
beta        =  0.33;  %added value of manufacturing
theta       =  2.59; % FROM Mayer et al
%theta       =  4.14; % FROM Ina Simonovskaa, b, , , Michael E. Waughc, 
theta_tilda =  1.84;
sigma       = theta/theta_tilda+1;
alphatilde  =  1.73;  %alpha*(sigma-1)          
delta       = -1.17;

% Old Paper
% beta        =  0.33;  %added value of manufacturing
% theta       =  5; %4.87;   %4.5
% theta_tilda =  1.2;
% sigma       = theta/theta_tilda+1;
% alphatilde  =  2.69;  %alpha*(sigma-1)          
% delta       = -1.4;

% Alvarez-Lucas Iteration Convergence Issues
AL.vfactor  = 0.1;              % Wage iteration term
AL.maxit    = 10000;            % Maximum iterations for wage or price mappings
AL.wtol     = .0000000000001;   % Tolerances for wage iteration
AL.ptol     = .0000000000001;   % Tolerances for price iteration
AL.display  = 0;                % Display Iterations

MaxPercCount        = 30000;    % number of simulated firms (put number that is easily divided by 10)
benchmarkcountry    = 7    ;    % benchmark country to compute firm-level results
n                   = 58   ;


%%
%---------------------
%Organizing the data
%---------------------
%Bilateral trade and deficit in manufactures
xbilat  =   trade00;        %Bilateral trade matrix, rows are exporters and columns are importers
xbilat  =   xbilat';        %We want exporters as columns
exports =   sum(xbilat);    %Aggregate exports by country
imports =   sum(xbilat');   %Aggregate imports by country
defm    =   imports-exports;%Deficit in manufactures by country
gdp=gdp00;                  %GDP data


catb=catb00;                %Current account and trade deficits in goods and services
catbw = catb(n,:);   %World total
catb(n,:) = catbw - sum(catb(1:n-1,:)); %We want Rest of the world (ROW) in the last row to balance the rest of the world.
catb = catb - ones(n,1)*catbw/n; %Spread the discrepancy evenly across all countries
tsurplus = catb(:,2);       %Second column is the trade of manufacturing goods balance

imports = sum(xbilat');
exports = sum(xbilat) ;

deficitm = imports-exports; %Deficit in manufactures


% we do not have data on manufacturing absorption for the Rest of the World (ROW). Thus, we construct it
%using the mean share of manufacturing absorption to gdp from our sample
%and applying that mean to the gdp of the ROW
absorp00(n)=mean(absorp00(1:n-1)./gdp(1:n-1))*gdp(n);
gammaone=(absorp00-(1-beta)*(1-1/sigma)*(absorp00-deficitm'))./(gdp00-tsurplus);
gamma=gammaone.*ones(n,1);

ym=absorp00-deficitm';   %Implied manufacturing production

xnn = absorp00 - imports'; %Home sales
xnimatrix = xbilat - diag(diag(xbilat)) + diag(xnn); %Spending matrix. First we put zeros and then we add home sales in the diagonal of the bilateral trade matrix.
xnn = diag(xnimatrix); %Home sales vector

xgdp = gdp - tsurplus; %Final spending
deficitt=-tsurplus;

%----------------------------------------
%Calculating the expenditure share matrix
%-----------------------------------------
xn = xnn + imports'; %Total spending by country
xn_div = xn*ones(1,n);
pimatrix = xnimatrix./xn_div; %Expenditure share matrix; ith country spent this much on jth country.

ALparams.beta     = beta;
ALparams.gamma    = gamma;
ALparams.theta    = theta;
ALparams.sigma    = sigma;
ALparams.delta    = delta;
% ALparams.delta2    = delta2;

ALparams.alphatilde    = alphatilde;

ALstart.ym        = ym;
ALstart.gdp       = gdp;
ALstart.deficitt  = deficitt;
ALstart.deficitm  = deficitm;
ALstart.xnimatrix = xnimatrix;
ALstart.pimatrix  = pimatrix;

%%

%---------------------------
%Defining counterfactuals
%---------------------------
fixedchange1    =.85    ;%fixed cost first good
fixedchangeall  =.85    ;%percent of fixed cost rem
icebergdrop     =1      ;%iceburg cost
deltadrop       =1      ;% Change in Delta
ALchanges = alvarez_lucas_counterfactuals( ALstart, ALparams,fixedchange1,fixedchangeall,icebergdrop,deltadrop);

fixedchange2    =.85      ;%percent of fixed cost rem
fixedchangeal2  =.85      ;%fixed cost first good
icebergdrop2    =1        ;%iceburg cost
deltadrop2      =1        ;% Change in Delta
ALchanges2 = alvarez_lucas_counterfactuals_differential( ALstart, ALparams,fixedchange2,fixedchangeal2,icebergdrop2,deltadrop2);

fixedchange3    =1        ;%percent of fixed cost rem
fixedchangeal3  =1        ;%fixed cost first good
icebergdrop3    =1        ;%iceburg cost
deltadrop3      =1.3      ;% Change in Delta
ALchanges3 = alvarez_lucas_counterfactuals( ALstart, ALparams,fixedchange3,fixedchangeal3,icebergdrop3,deltadrop3);

fixedchange4    =1        ;%percent of fixed cost rem
fixedchangeal4  =1        ;%fixed cost first good
icebergdrop4    =1        ;%iceburg cost
deltadrop4      =1.30     ;% Change in Delta
ALchanges4 = alvarez_lucas_counterfactuals_differential( ALstart, ALparams,fixedchange4,fixedchangeal4,icebergdrop4,deltadrop4);

fixedchange5    =1    ;%fixed cost first good
fixedchangeal5  =1    ;%percent of fixed cost rem
icebergdrop5     =.96      ;%iceburg cost
deltadrop5       =1      ;% Change in Delta
ALchanges5 = alvarez_lucas_counterfactuals( ALstart, ALparams,fixedchange5,fixedchangeal5,icebergdrop5,deltadrop5);


% ----------------------
%Alvarez-Lucas algorithm
%-----------------------
ALfinish  = alvarez_lucas(AL, ALchanges,  ALstart, ALparams)
ALfinish2 = alvarez_lucas(AL, ALchanges2, ALstart, ALparams)
ALfinish3 = alvarez_lucas(AL, ALchanges3, ALstart, ALparams)
ALfinish4 = alvarez_lucas(AL, ALchanges4, ALstart, ALparams)
ALfinish5 = alvarez_lucas(AL, ALchanges5, ALstart, ALparams)

%----------------------------------
% Defining counterfactuals results
%----------------------------------
ALresults  = alvarez_lucas_results( ALstart, ALfinish , ALparams, ALchanges  );
ALresults2 = alvarez_lucas_results( ALstart, ALfinish2, ALparams, ALchanges2 );
ALresults3 = alvarez_lucas_results( ALstart, ALfinish3, ALparams, ALchanges3 );
ALresults4 = alvarez_lucas_results( ALstart, ALfinish4, ALparams, ALchanges4 );
ALresults5 = alvarez_lucas_results( ALstart, ALfinish5, ALparams, ALchanges5 );

%%----------------------------------------------
% Tables
%----------------------------------------------
list=1:n';
CountryNames = {'Armenia','Australia','Austria','Azerbaijan','BelgmLuxNthl', ...
    'Bolivia','Brazil','Bulgaria','Canada','Chile','ChinaHKG','Colombia', ...
    'CostaRica','Cyprus','Ethiopia','Finland','FranceMonaco','Germany', ...
    'Hungary','IndMalSgThai','India','Iran','Ireland','Israel','Italy',...
    'Japan','Jordan','Kazakhstan','Kenya','Kuwait','Kyrgyzstan','Latvia',...
    'Lithuania','Malta','Mexico','Morocco','Norway','Oman','Poland','Portugal',...
    'Romania','RussianFed','Senegal','Slovenia','SouthKorea','Spain','SriLanka',...
    'Sweden','TrinidadTbg','Tunisia','Turkey','UK','USA','Ukraine','Uruguay'...
    ,'VietNam','Yemen','RestOfWorld'};
% fprintf('\nTable 4: Consequences of Counterfactual\n')
% fprintf('Count\tReal W\tReal W\t RealW\n')
% fprintf(' \tf(g)\tf(1)\ttau\n')
% for i=1:length(list)
%     fprintf('%2.0f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,list(i),(ALresults.welfare(i)-1)*100,(ALresults2.welfare(i)-1)*100,(ALresults3.welfare(i)-1)*100,CountryNames{i} )
% end
% disp(['Real W=Ratio change in real wages'])


% fprintf('\nTable 4: Consequences of Counterfactual\n')
% fprintf('Count\tRealW\tRealW\tRealW\tRealW\n')
% fprintf(' \t1\t2\t3\n')
% for i=1:length(list)
%     fprintf('%2.0f\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,list(i),(ALresults.drealw(i)-1)*100,(ALresults2.drealw(i)-1)*100,(ALresults3.drealw(i)-1)*100,(ALresults4.drealw(i)-1)*100,CountryNames{i} )
% end
% fprintf('%2.0f\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,00,mean((ALresults.drealw-1)*100),mean((ALresults2.drealw-1)*100),mean((ALresults3.drealw-1)*100),mean((ALresults4.drealw-1)*100),'Mean')

% disp(['Real W=Ratio change in real wages'])

theta_str = num2str(theta,3);
fid = fopen([root 'Results/Tables/' 'Table_counterfactals_welfare_theta_' theta_str '.txt'], 'w');
fprintf(fid,'tab:counterfactuals-results\n\n');

fprintf(fid,'No\tWelfare\tWelfare\tWelfare\tWelfare\tCountry\n');
fprintf(fid,' \t1\t2\t3\t4\n');
for i=1:length(list)
    fprintf(fid,'%2.0f\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,list(i),(ALresults.welfare(i)-1)*100,(ALresults2.welfare(i)-1)*100,(ALresults3.welfare(i)-1)*100,(ALresults4.welfare(i)-1)*100,CountryNames{i} );
end
fprintf(fid,'%2.0f\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,00,mean((ALresults.welfare-1)*100),mean((ALresults2.welfare-1)*100),mean((ALresults3.welfare-1)*100),mean((ALresults4.welfare-1)*100),'Mean');

% Latex Output
fprintf(fid,'\n\ntab:counterfactuals-results\n\n');

for i=1:floor(length(list)/2)
    fprintf(fid,'%-15s & %5.2f & %5.2f & %5.2f & %5.2f & & '  ,CountryNames{i}     ,(ALresults.welfare(i)-1)*100,(ALresults2.welfare(i)-1)*100,(ALresults3.welfare(i)-1)*100,(ALresults4.welfare(i)-1)*100 );
    fprintf(fid,'%-15s & %5.2f & %5.2f & %5.2f & %5.2f \\\\\n'  ,CountryNames{29+i}  ,(ALresults.welfare(29+i)-1)*100,(ALresults2.welfare(29+i)-1)*100,(ALresults3.welfare(29+i)-1)*100,(ALresults4.welfare(29+i)-1)*100 );
end
fprintf(fid,'\\cline{8-11} & & & & & &  %30s            & %5.2f & %5.2f & %5.2f & %5.2f \\\\ \n'  ,'Mean',mean((ALresults.welfare-1)*100),mean((ALresults2.welfare-1)*100),mean((ALresults3.welfare-1)*100),mean((ALresults4.welfare-1)*100));


% Punchline
fprintf(fid,'\n\n\n');
fprintf(fid,'Run 1: Drop F\n');
fprintf(fid,'Run 1: Harmonize F\n');
fprintf(fid,'Run 1: Drop Delta\n');
fprintf(fid,'Run 1: Harmonize Delta\n');
fprintf(fid,'Run 1: Drop Tariffs\n');
fprintf(fid,'Run              :\t 1    \t 2    \t 3    \t 4    \t 5    \t    \n'  );
fprintf(fid,'Mean Welfare Gain:\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%5.2f\t%s  \n'  ,mean((ALresults.welfare-1)*100),mean((ALresults2.welfare-1)*100),mean((ALresults3.welfare-1)*100),mean((ALresults4.welfare-1)*100),mean((ALresults5.welfare-1)*100),'Mean');

