function [ ALfinish ] = alvarez_lucas(AL, ALchanges, ALstart, ALparams)
   %% ----------------------
    %Alvarez-Lucas algorithm
    %-----------------------

    icebergchangemat = ALchanges.icebergchangemat;
    fixedcostmat     = ALchanges.fixedcostmat;
    deftc            = ALchanges.deftc;
    defmc            = ALchanges.defmc;

    ym        = ALstart.ym;
    gdp       = ALstart.gdp;
    deficitt  = ALstart.deficitt;
    deficitm  = ALstart.deficitm;
    xnimatrix = ALstart.xnimatrix;
    pimatrix  = ALstart.pimatrix;

    beta      = ALparams.beta;
    gamma     = ALparams.gamma;
    theta     = ALparams.theta;
    sigma     = ALparams.sigma;
    
    y0 = (gdp.*(1+(sigma-1).*(beta-gamma/theta))-((sigma-1).*gamma/theta).*deficitt+(sigma-1)/theta.*deficitm')/(1+(sigma-1)*beta);
    %y0=gdp;
    %testlabor=y0+(sigma-1)/sigma/theta*gdp
    n=size(deficitm,2);

    % Initialize vectors of ex-post wage and price factors
    wf0 = ones(n,1);
    pf0 = ones(n,1);


    % iteration on wages and prices %
    prueba_w = 2*AL.wtol;
    i = 0;
    iter=0;
    while ((i <= AL.maxit) && (prueba_w > AL.wtol))
        if AL.display == 1
            fprintf('\titeration: %2.0f, %12.12g\n',iter,prueba_w)
        end
        prueba_p = 2*AL.ptol;
        j = 0;

        %iterate to find prices
        while ((j <= AL.maxit) && (prueba_p > AL.ptol))
            pf1=exp(-(1/theta)*log(pimatrix.*icebergchangemat.^(-theta).*(fixedcostmat)*exp(-theta*(beta*log(wf0)+(1-beta)*log(pf0))))).*((1.+deftc./(wf0.*y0))./(1.+deftc./y0)).^(1/theta-1/(sigma-1));
            prueba_p=sum(abs(pf1-pf0));
            pf0 = pf1;
            j = j+1;
        end;


        %computing the shares
        xnimatrix1=pimatrix.*((ones(n,1)*((wf0.^beta).*(pf1.^(1-beta)))').^(-theta)).*icebergchangemat.^(-theta).*fixedcostmat;
        xn = sum(xnimatrix1,2) * ones(1,n);
        pimatrix1 = xnimatrix1./xn;

        %iterate to find wages

        %%%market clearing from Muendler-Arko
        zw = (pimatrix1'*(((sigma*gamma.*(wf0.*y0+deftc))  - (sigma-1)*(1-beta+gamma/theta).*defmc')./(1+(sigma-1)*(beta-gamma/theta)))...
            - ((sigma*gamma.*(wf0.*y0+deftc))  -sigma*defmc')./(1+(sigma-1)*(beta-gamma/theta)))./wf0; %excess of demand equation


        %testing zw function
        %AA=ym-defmc'-((sigma*gamma.*(wf0.*y0+deftc))  - (sigma-1)*(1-beta+gamma/theta)*defmc');
        A=ym-((sigma*gamma.*(wf0.*y0+deftc))  -sigma*defmc')./(1+(sigma-1)*(beta-gamma/theta));

        wf1 = wf0.*(1+AL.vfactor*zw./y0);

        prueba_w=sum(abs(wf1-wf0));
        wf0 = wf1;
        iter=iter+1;
        i = i+1;
    end;
    
    ALfinish.xnimatrix1 = xnimatrix1;
    ALfinish.pimatrix1  = pimatrix1;
    ALfinish.wf1  = wf1;
    ALfinish.pf0  = pf0;
    ALfinish.pf1  = pf1;
    ALfinish.y0   = y0;
end

