% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%% Master Program
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
     root =  './2013_Multiproducts/'
     
     dirs_DATA = [root 'Data/']
     dirs_EST  = [root 'EstimationSMM-v6-ratios/']
     dirs_PLOT = [root 'EstimationSMM-v6-ratios/Plot_Routines/']
     dirs_CF   = [root 'Counterfactuals/']
     addpath(dirs_DATA,dirs_EST,dirs_CF)
     
% ----------------------------------------------------------------------------------------
%% Run Stata Program to Format Data into Usable format
% Also run some preliminary regressions
% ----------------------------------------------------------------------------------------
%   [~,cmdout] = system('chmod +rwx stata.bat','-echo')
%   [~,cmdout] = system('./Data/stata.bat','-echo')

    [~,cmdout] = system(['module load Apps/Stata; stata -b do ' dirs_DATA 'Brazil_Matlab_Prep_v3.do'],'-echo')

% ----------------------------------------------------------------------------------------
%% Read in Stata Program Output
% ----------------------------------------------------------------------------------------
% Raw Data for only manufacturing companies
%       100          80       10188
% ----------------------------------------------------------------------------------------
    filename = [dirs_DATA '/Output/Brazil_Matlab_80co_100pr_mfged_count.csv'];
    savename = [dirs_EST  'Brazil_Matlab_80co_100pr_mfged_count.mat'];
    [ Brazil_data] = Import_Brazil( filename, 100, savename );

% ----------------------------------------------------------------------------------------
% Adjusted Data for only manufacturing companies
%       100          80       10188
% ----------------------------------------------------------------------------------------
    filename = [dirs_DATA '/Output/Brazil_Matlab_80co_100pr_mfged_adj_count.csv'];
    savename = [dirs_EST  'Brazil_Matlab_80co_100pr_mfged_adj_count.mat'];
    [ Brazil_data] = Import_Brazil( filename, 100, savename );
      
% ----------------------------------------------------------------------------------------
% Only including the categories
%       //DK    Manufacture of machinery and equipment n.e.c.
%       //DL    Manufacture of electrical and optical equipment
%       //DM    Manufacture of transport equipment
%       100          80        2539
% ----------------------------------------------------------------------------------------
    filename = [dirs_DATA '/Output/Brazil_Matlab_40co_100pr_mfged_highvol_count.csv'];
    savename = [dirs_EST  'Brazil_Matlab_40co_100pr_mfged_highvol_count.mat'];
    [ Brazil_data] = Import_Brazil( filename, 100, savename );
      
% ----------------------------------------------------------------------------------------
% USE HS8 not HS6 data
% ----------------------------------------------------------------------------------------
    filename = [dirs_DATA '/Output/Brazil_Matlab_40co_100pr_mfged_hs8_count.csv'];
    savename = [dirs_EST  'Brazil_Matlab_40co_100pr_mfged_hs8_count.mat'];
    [ Brazil_data] = Import_Brazil( filename, 100, savename );

% ----------------------------------------------------------------------------------------
%% Run Optimization Wrapper
% We run this program separately 500 times to get all boostrapped issues and so on
% This uses the bsub IBM supercomputer batch submission script to submit 500 iterations
% ----------------------------------------------------------------------------------------
    for i = 1:1 %400
        [~,cmdout] = system('bsub < Multiproducts_LSF.sh; sleep 3','-echo')
    end

% ----------------------------------------------------------------------------------------
%% Get Estimates
% ----------------------------------------------------------------------------------------
    get_estimate_wrapper

% ----------------------------------------------------------------------------------------
%% Plot Data
% ----------------------------------------------------------------------------------------
    make_plots_master

% ----------------------------------------------------------------------------------------
%% Run Counterfactuals
% ----------------------------------------------------------------------------------------
     AGM_EKK_counterfactual
     
 